                #### -- Functions for appendages & shield measurements processing 

#Import data
import<- function(x,z){
  datam<-paste(x,z,sep = "/") #path to files
  fil<-list.files(datam) #list files from folder
  format<-grepl("Shield",datam) #type of data
  if (format==T){ #shield measurements
    measures<-data.frame(Ls=numeric(), Lr=numeric(), Lw=numeric(), Ha=numeric(), Hmax=numeric(), Hp=numeric(), Aad=numeric(), 
                         Aav=numeric(), Apv=numeric(), Apd=numeric()) #names of measurements
    for (i in 1:length(fil)){
      spec<-read.csv(paste(datam, fil[i], sep='/')) #read file
      measures<-rbind(measures,c(spec$Length[1:6],spec$Angle[7:10]))
    }
    rownames(measures)<- gsub(".csv", "", fil)
    colnames(measures)<-c("Ls","Lr", "Lw", "Ha", "Hmax", "Hp", "Aad", "Aav", "Apv", "Apd")
    return(measures)
  }
  else { #appendages measurements
    measures<-data.frame(matrix(nrow = 0, ncol = 60))
    for (i in 1:length(fil)){
      spec<-read.csv(paste(datam, fil[i], sep='/'))
      measures<-rbind(measures,spec$Length)
    }
    rownames(measures)<- gsub(".csv", "", fil)
    return(measures)
  }
}

#change 0 into NA
nonapp<-function(x){
  for (d in 1:ncol(x)){
    for (f in 1:nrow(x)){
      if (x[f,d]==0 | 0.000){
        x[f,d]<-as.numeric(NA)
      }
    }
  }
  return(x)
}

#Rounded & log measurements for allometric analyses
rdlog<-function(x){
  for (i in 1:ncol(x)){
    x[,i]<-as.numeric(x[,i])
    for (j in 1:nrow(x)){
      if (is.numeric(x[j,i])==T){
        x[j,i]<-round(log(x[j,i]),1)
      }
    }  
  }
  return(x)
}

#Rounded measurements
rd<-function(x){
  for (i in 1:ncol(x)){
    x[,i]<-as.numeric(x[,i])
    for (j in 1:nrow(x)){
      if (is.numeric(x[j,i])==T){
        x[j,i]<-round(x[j,i],2)
      }
    }  
  }
  return(x)
}

#Average of part and counter-part of each specimen
avg<-function(x){
  specimen<-gsub("(_)([a-z]{1,})", "",rownames(x)) # found specimen numbers
  l<-c()
  typedata<-grepl("species",colnames(x[(ncol(x))])) #if multiple species in the table
  if (typedata==T){
    w<-subset(x,select=-c(species))
    for (i in 1:(nrow(x)-1)){
      if (specimen[i]==specimen[(i+1)]){
        l=c(l,i,i+1)
        z<-rbind(w[i,],w[i+1,])
        moy<-c(colMeans(z, na.rm = T),x$species[i])
        x<-rbind(x,moy)
        rownames(x)[nrow(x)]<-specimen[i]
      }
    }
  }
  else{ #if only one species
    for (i in 1:(nrow(x)-1)){
      if (specimen[i]==specimen[(i+1)]){
        l=c(l,i,i+1)
        z<-rbind(x[i,],x[i+1,])
        x<-rbind(x,colMeans(z, na.rm = T))
        rownames(x)[nrow(x)]<-specimen[i]
      }
    }
  }
  if (length(l)!=0){
    x<-x[-(l),]
  }
  return(x)
}

#Burnaby's size-correction
##from Blankers et al.2012, modified by Eberle et al. 2015 
bsc<-function(data){
  f.iso <- array(1,dim=ncol(data))/sqrt(ncol(data)) #Find isometric size vector
  shape <- log(data)%*%(diag(ncol(data))-(f.iso%*%solve(t(f.iso)%*%f.iso)%*%t(f.iso))) # calculate shape based on isometric size vector
  return(shape)
}

#add Mean of measures to dataframe
meanmeas<-function(x){
  l<-c()
  for (d in 1:ncol(x)){
    m<-round(mean(x[,d], na.rm=T),2)
    l<-c(l,m)
  }
  x<-rbind(x,l)
  rownames(x)[nrow(x)]<-"Means"
  return(x)
}

#ratio between length and width of an element of an appendage
ratio<-function(x){
  rat<-data.frame(matrix(nrow = 0, ncol = (ncol(x)/2)))
  for (i in 1:nrow(x)){
    y=1
    l=c()
    while (y<ncol(x)){
      w=y+1
      v<-round(x[i,y]/x[i,w],2)
      l<-c(l,v)
      y=y+2
    }
    rat<-rbind(rat,l)
  }
  rownames(rat)=rownames(x)
  return(rat)
}

#create table for SMA
sma_table<-function(x,group=1){
  z<-x[["coef"]][[group]][["coef(SMA)"]] #intercept and slope
  z<-c(z,x[["r2"]][[group]][[1]]) #R2
  z<-c(z, x[["pval"]][[group]][[1]]) #p-value
  z<-signif(as.data.frame(z), 3) #round data (significative numbers)
  colnames(z)<-gsub("_sma","",deparse(substitute(x))) #names of variables (columns)
  rownames(z)<-c('elevation', 'slope', "R2", "p-Value") #names of coefficients (rows)
  return(z)
}