                ### -- La Voulte thylacocephalans - Paraostenia voultensis shield allometry -- ###

#Libraries
  ##Graphics
library(ggplot2)
library(cowplot)
library(RColorBrewer)
library(factoextra) #PCA
library(gridExtra) #table
library(gtsummary) #table
  
  ##Statistics
library(missMDA) #missing data
library(FactoMineR) #PCA
library(smatr) #Standardised major axis analysis
library(NbClust) #K-means

#Functions
source("script/function_allometry.R")

#Data

  ##Import shield measurements
paraostenia<-import("Data/Paraostenia","Shield")

  ##Preparation

    ###NaN
paraostenia<-nonapp(paraostenia)

    ###Remove lr, lw
paraostenia<-paraostenia[-(2:3)]

    ###Rounded measurements
paraostenia_rd<-rd(paraostenia)

    ###Rounded & log measurements
paraostenia_round_log<-rdlog(paraostenia)

    ###Average part & counter part
paraostenia_rd_clean<-avg(paraostenia_rd) #not log-transformed (used for histogram)
paraostenia_round_log_clean<-avg(paraostenia_round_log) #log transformed dataset
paraostenia_round_log_clean$morphotype<-c(rep("morphotype 2", 12), "morphotype 1", rep("morphotype 2", 5), 
                                          "morphotype 1", "morphotype 2", "morphotype 1", rep("morphotype 2", 6), 
                                          "morphotype 1", rep("morphotype 2", 16)) 
                                          

#Statistical analyses

  ##Histogram for each measurements
hist_ls<-ggplot(paraostenia_rd_clean, aes(Ls))+
  geom_histogram(color="white",fill="darkblue", bins=18, size = 1)+
  theme_minimal()+
  theme(axis.title.x = element_text(face = "bold", size = 8), axis.text = element_text(size=6))+
  labs(y="", x="Ls (mm)")

hist_hmax<-ggplot(paraostenia_rd_clean, aes(Hmax))+
  geom_histogram(color="white",fill="darkblue", bins=18, size = 1)+
  theme_minimal()+
  theme(axis.title.x = element_text(face = "bold", size = 8), axis.text = element_text(size=6))+
  labs(y="", x="Hmax (mm)")

hist_ha<-ggplot(paraostenia_rd_clean, aes(Ha))+
  geom_histogram(color="white",fill="darkblue", bins=18, size = 1)+
  theme_minimal()+
  theme(axis.title.x = element_text(face = "bold", size = 8), axis.text = element_text(size=6))+
  labs(y="", x="Ha (mm)")

hist_hp<-ggplot(paraostenia_rd_clean, aes(Hp))+
  geom_histogram(color="white",fill="darkblue", bins=18, size = 1)+
  theme_minimal()+
  theme(axis.title.x = element_text(face = "bold", size = 8), axis.text = element_text(size=6))+
  labs(y="", x="Hp (mm)")

hist_aad<-ggplot(paraostenia_rd_clean, aes(Aad))+
  geom_histogram(color="white",fill="darkblue", bins=18, size = 1)+
  theme_minimal()+
  theme(axis.title.x = element_text(face = "bold", size = 8), axis.text = element_text(size=6))+
  labs(y="", x = "Aad (°)")

hist_aav<-ggplot(paraostenia_rd_clean, aes(Aav))+
  geom_histogram(color="white",fill="darkblue", bins=18, size = 1)+
  theme_minimal()+
  theme(axis.title.x = element_text(face = "bold", size = 8), axis.text = element_text(size=6))+
  labs(y="", x = "Aav (°)")

hist_apv<-ggplot(paraostenia_rd_clean, aes(Apv))+
  geom_histogram(color="white",fill="darkblue", bins=18, size = 1)+
  theme_minimal()+
  theme(axis.title.x = element_text(face = "bold", size = 8), axis.text = element_text(size=6))+
  labs(y="", x = "Apv (°)")+
  scale_x_continuous(breaks = c(80,100,120))

hist_apd<-ggplot(paraostenia_rd_clean, aes(Apd))+
  geom_histogram(color="white",fill="darkblue", bins=18, size = 1)+
  theme_minimal()+
  theme(axis.title.x = element_text(face = "bold", size = 8), axis.text = element_text(size=6))+
  labs(y="", x ="Apd (°)" )

histo<-arrangeGrob(hist_ls, hist_ha, hist_hmax, hist_hp, hist_aad, hist_aav, hist_apv, hist_apd, nrow = 2) #all histograms in one plot
grid.arrange(histo) #visualise
ggsave("Figure_25.svg", histo, path = "Figures", width = 160, height = 100, units = "mm") #save figure

  ## Testing the normality of the measurements
lapply(1:8, function (y) shapiro.test(paraostenia_rd_clean[,y])) #Shapiro-Wilk test
lapply(1:8, function (y) qqnorm(paraostenia_rd_clean[,y])) #Normal Q-Q plot

  ##Bivariate analyses

    ###SMA analyses
paraostenia_sma<-sma(Hmax~Ls,paraostenia_round_log_clean, robust = T, method = "SMA") #with no groups (morphotype)
paraostenia_sma_group<-sma(Hmax~Ls+morphotype,paraostenia_round_log_clean, robust = T, method = "SMA", shift=T) #with groups
summary(paraostenia_sma_group)

    ###scatter/Q-Q/residual plots
svg("Figures/Figure_26.svg", width=6.3, height = 4.7, pointsize = 9)
par(mfrow=c(2,2))
plot(paraostenia_sma, main="SMA (no groups)", xlab = "Log(Ls) (mm)", ylab = "Log(Hmax) (mm)", font.lab = 2)
plot(paraostenia_sma_group, main ="SMA (morphotypes)", xlab = "Log(Ls) (mm)", ylab = "Log(Hmax) (mm)", font.lab = 2)
plot(paraostenia_sma, which = "res", main = "Residuals vs fitted", font.lab = 2)
plot(paraostenia_sma, which = "qq", font.lab = 2)
dev.off()

    ###summary table
summary(paraostenia_sma_group) #no difference in lines = same allometric line, thus ontogenetic line
paraostenia_coef<-cbind(sma_table(paraostenia_sma_group, "morphotype 1"), sma_table(paraostenia_sma_group, "morphotype 2"))
colnames(paraostenia_coef)<-c("morphotype 1", "morphotype 2")
write.csv(paraostenia_coef,"Export/sma_coef_paraostenia.csv")
paraostenia_sma_export<-grid.table(paraostenia_coef, rows=c("elevation", "slope", expression(paste("R"^"2")), "p-Value"), 
                                   theme = ttheme_default(base_size=10)) 
                                  #visualise table
paraostenia_sma_coef_table<-tableGrob(paraostenia_coef, rows=c("elevation", "slope", expression(paste("R"^"2")), "p-Value"), 
                                      theme = ttheme_default(base_size=4.5, base_family = "serif", rowhead = list(fg_params=list(fontface=c("italic"))))) 
                                      #save table with coefficients
ggsave("Table_4.tiff", paraostenia_sma_coef_table, path = "Figures", width= 981, height=500, dpi = 300, units = "px")#export table
  
  ##Multivariate analyses
    
    ###PCA
set.seed(123)
estim_ncpPCA(paraostenia_round_log_clean[1:8],ncp.min=1, ncp.max=8, scale = T, method = "EM", nbsim = 100) #Estimate the number of dimensions for the Principal Component Analysis by cross-validation
      
      ####missing value
paraostenia_missing<-imputePCA(paraostenia_round_log_clean[1:8], ncp=1, method = "EM", scale = T) #impute missing data
paraostenia_bsc<-bsc(paraostenia_missing$completeObs) #Burnaby's size-correction
colnames(paraostenia_bsc)<-colnames(paraostenia_round_log_clean[1:8])

      #####run PCA
paraostenia_pca<-PCA(paraostenia_bsc, scale.unit = T, ncp = 7)
paraostenia_pca_coord<-paraostenia_pca$ind$coord

      #####Eigenvalues
eig<-t(get_eigenvalue(paraostenia_pca))

      #####Factor loadings
factor_load<-paraostenia_pca$var$contrib
rownames(factor_load)<-c("Log(Ls)", "Log(Ha)", "Log(Hmax)", "Log(Hp)", "Log(Aad)","Log(Aav)", "Log(Apv)", "Log(Apd)")

      #####Export eigenvalues and factor loadings
eig_fact<-rbind(eig[,1:7], factor_load)
colnames(eig_fact)<-gsub("\\.", "ension ", colnames(eig_fact)) #names of dimensions (columns)
grid.table(eig_fact, theme = ttheme_default(base_size=5, base_family = "serif"))
eig_fact_table<-tableGrob(eig_fact, theme = ttheme_default(base_size=5, base_family = "serif"))
ggsave("Table_5.tiff", eig_fact_table, path = "Figures", width = 1961, height=900, units = "px", dpi = 300)    
    
    ###clustering

      ####Assesing clustering tendency
set.seed(123)
get_clust_tendency(paraostenia_pca_coord, 43)

      #####Determining optimal number of clusters
set.seed(123)
NbClust(paraostenia_pca_coord, method = "kmeans")

      #####K-Means analysis
set.seed(123)
paraostenia_kmeans<-kmeans(paraostenia_pca_coord, 3, nstart = 25)
paraostenia_cluster<-as.data.frame(paraostenia_kmeans$clusters)
rownames(paraostenia_cluster)<-rownames(paraostenia_bsc)

      #####Comparison K-Means-description
table(paraostenia_round_log_clean$morphotype, paraostenia_kmeans$cluster)

      ##### Visualisation
clust_palette<-c("blue3", "darkgoldenrod2","darkgoldenrod1")
graph_clust<-fviz_cluster(paraostenia_kmeans, paraostenia_bsc, palette=clust_palette, geom="point",main="A",ggtheme = theme_minimal())+ 
  theme(title = element_text (size=12), legend.position = c(0.05,0.15), legend.background = element_rect(colour = "white", fill="white", size = 7), 
        legend.title = element_text(face = 2, size=8), legend.text = element_text(size=8), legend.margin = margin(1,1,1,1), 
        axis.title = element_text(face = 2, size=8), axis.text =element_text(size=7)) #morphospace with cluster of K-means as group
graph_cor<-fviz_pca_var(paraostenia_pca, repel = T, title = "B")+theme(title = element_text (size=12),axis.title = element_text(face = 2, size=8), axis.text=element_text(size=7)) #correlation circle of variable

pca_plots<-ggdraw() +
  draw_plot(graph_clust, x = 0, y = 0.4, width = 1, height = 0.6) +
  draw_plot(graph_cor, x = 0, y = 0, width = 1, height = 0.4) #combine into subplots
pca_plots
ggsave("Figure_22.tiff", pca_plots, path = "Figures", width = 160, height = 180, units = "mm", dpi = 300)
