                      ### -- La Voulte thylacocephalans - shield -- ###

### -- La Voulte thylacocephalans - Shield allometry -- ###

#Libraries
library(dplyr)
library(ggplot2)
library(gridExtra)
library(gtsummary)
library(gt)
library(webshot)
library(smatr)


#Functions
source("script/function_allometry.R")

#Data
  ##Import
clausocaris_shield<-import("Data/Clausocaris",'Shield') #Measurements for Clausocaris harpa
kilianicaris_shield<-import("Data/Kilianicaris","Shield") #Measurements for Kilianicaris lerichei
mayrocaris_shield<-import("Data/Mayrocaris","Shield") #Measurements for Mayrocaris sp.
ostenocaris_shield<-import("Data/Ostenocaris",'Shield') #Measurements for Ostenocaris ribeti
ovalicaris_shield<-import("Data/Ovalicaris-secretanae","Shield") #Measurements for Ovalicaris secretana
paraostenia_shield<-import("Data/Paraostenia","Shield") #Measurements for Paraostenia voultensis

#Descriptive statistics

  ##merge multiple tables into one
shield<-rbind(clausocaris_shield,kilianicaris_shield,mayrocaris_shield,ostenocaris_shield,ovalicaris_shield,paraostenia_shield)

  ##add NaN instead of 0
shield_na<-nonapp(shield)

  ##add species names
shield_na$species<-c(replicate(nrow(clausocaris_shield), "Clausocaris harpa"), replicate(nrow(kilianicaris_shield),"Kilianicaris lerichei"),
                  replicate(nrow(mayrocaris_shield),"Mayrocaris sp."), replicate(nrow(ostenocaris_shield),"Ostenocaris ribeti"), 
                  replicate(nrow(ovalicaris_shield), "Ovalicaris secretanae"), replicate(nrow(paraostenia_shield),"Paraostenia voultensis"))

  ##Average part & counter part
shield_clean<-avg(shield_na)
for (i in 1:(ncol(shield_clean)-1)){
  shield_clean[,i]<-as.numeric(as.character(shield_clean[,i]))
}

  ##table for export
tbl_descstat<-tbl_summary(shield_clean, by=species, type = all_continuous()~"continuous2",
            statistic= list(all_continuous()~c("{mean} ({sd})", "{min}-{max}")), 
            digits = all_continuous()~2, missing_text = "Missing data", label = list(Ls = "Ls (mm)", 
            Lr = "Lr (mm)", Lw="Lw (mm)", Ha="Ha (mm)", Hmax='Hmax (mm)',Hp="Hp (mm)", Aad="Aad (°)",
            Aav="Aav (°)", Apv='Apv (°)', Apd='Apd (°)', stat_0='Min-Max'))%>% bold_labels()%>%modify_header(update=list(label~"**Measurements**", all_stat_cols()~"***{level}*** (N = {n})"))
tbl_descstat_gt<-as_gt(tbl_descstat)%>%opt_table_font("serif")
gtsave(tbl_descstat_gt,"Table_2-descriptive-statistics.rtf", path="Figures")


#Simple allometry

  ##cleaned data for each species
clausocaris_clean<-filter(shield_clean, species == "Clausocaris harpa")
kilianicaris_clean<-filter(shield_clean, species == "Kilianicaris lerichei")
ostenocaris_clean<-filter(shield_clean, species == "Ostenocaris ribeti")
paraostenia_clean<-filter(shield_clean, species == "Paraostenia voultensis")

  ##standardised major axis (SMA) analysis for each species
clausocaris_sma<-sma(Hmax~Ls, clausocaris_clean, robust = T, log = "xy")
kilianicaris_sma<-sma(Hmax~Ls, kilianicaris_clean, robust = T, log = "xy")
ostenocaris_sma<-sma(Hmax~Ls, ostenocaris_clean, robust = T, log = "xy")
paraostenia_sma<-sma(Hmax~Ls, paraostenia_clean, robust = T, log = "xy")

  ##coefficient table for each SMA
clausocaris_coef<-sma_table(clausocaris_sma) #Clausocaris harpa
kilianicaris_coef<-sma_table(kilianicaris_sma) #Kilianicaris lerichei
ostenocaris_coef<-sma_table(ostenocaris_sma) #Ostenocaris ribeti
paraostenia_coef<-sma_table(paraostenia_sma) #Paraostenia voultensis
sma_coef<-cbind(clausocaris_coef, kilianicaris_coef, ostenocaris_coef, paraostenia_coef) #combine every species
colnames(sma_coef)<-c("Clausocaris harpa", "Kilianicaris lerichei", "Ostenocaris ribeti", "Paraostenia voultensis") #add species names
write.csv(sma_coef, "Export/sma_coef.csv")
sma_export<-grid.table(sma_coef, theme = ttheme_default(base_size=10, colhead = list(fg_params=list(fontface=c("bold.italic"))))) #visualise table
sma_coef_table<-tableGrob(sma_coef,rows=c("elevation", "slope", expression(paste("R"^"2")), "p-Value"), theme = ttheme_default(base_size=10, base_family = "serif", colhead = list(fg_params=list(fontface=c("bold.italic"))))) #save table with coefficients
ggsave("Table_3.tiff", sma_coef_table, path = "Figures", width= 1961, height=800, dpi = 300, units = "px")

  ##scatter plot for every species with standardised major axis
svg("Figures/Figure_3.svg", width = 6.3, height = 4.7, pointsize = 6)
par(mfrow=c(2,2))
plot(clausocaris_sma, main="Clausocaris harpa",xlab = "Ls (mm)", ylab = "Hmax (mm)", font.main = 4, font.lab=2, col="tomato2", pch = 19, lwd=1)
plot(kilianicaris_sma, main ="Kilianicaris lerichei",xlab = "Ls (mm)", ylab = "Hmax (mm)", font.main = 4, font.lab=2, col="tomato2", pch = 19, lwd=1)
plot(ostenocaris_sma, main = "Ostenocaris ribeti",xlab = "Ls (mm)", ylab = "Hmax (mm)", font.main = 4, font.lab=2, col="tomato2", pch = 19, lwd=1)
plot(paraostenia_sma, main = "Paraostenia voultensis",xlab = "Ls (mm)", ylab = "Hmax (mm)", font.main = 4, font.lab=2, col="tomato2", pch = 19, lwd=1)
dev.off()
